{ lib     ? import <nixpkgs/lib>
, pkgsFun ? import <nixpkgs>
}:
let
  nixpkgsArgs = { config.allowNonSource = false; };
  nixpkgsOnBuildForBuild  = pkgsFun nixpkgsArgs;

  ownerboot = { hostPlatform?null, overlay }:
    (lib.makeScope lib.callPackageWith (self: {
      inherit lib nixpkgsOnBuildForBuild;

      nixpkgsOnBuildForHost   = pkgsFun
        (nixpkgsArgs // (lib.optionalAttrs (hostPlatform!=null) {
          crossSystem = hostPlatform; }));

      coreboot-toolchain = self.callPackage ./coreboot-toolchain { };

      iasl_20180531 = self.nixpkgsOnBuildForBuild.callPackage ./coreboot/iasl_20180531 { };
      coreboot      = self.callPackage ./coreboot {
        initramfs_image = self.initramfs;
      };
      kernel        = self.callPackage ./kernel { };
      userspace = self.callPackage ./userspace { };
      initramfs     = self.callPackage ./initramfs { };
    }))
  .overrideScope' overlay;
in {
  # one entry for each supported platform
  kevin = ownerboot (import ./platform/kevin);
  am1i  = ownerboot (import ./platform/am1i);
  kgpe  = ownerboot (import ./platform/kgpe);

  em100 = nixpkgsOnBuildForBuild.callPackage ./util/em100 { };
  flashrom = nixpkgsOnBuildForBuild.callPackage ./flashrom { };
}


